nxp-pac

Crates

git

Versions

mcxa577

Flavors

Popcode0

Struct Popcode0 

#[repr(transparent)]
pub struct Popcode0(pub u32);
Programmable OP Code0

Tuple Fields

0: u32

Implementations

Source

impl Popcode0

pub const fn filter_state0(&self) -> u8

Programmable Filter state 0

pub const fn set_filter_state0(&mut self, val: u8)

Programmable Filter state 0

pub const fn filter_bit0(&self) -> FilterBit0

This bit determines whether the Programmable Op Code filter is executed after receipt of the 7th or 8th bit of the Op Code

pub const fn set_filter_bit0(&mut self, val: FilterBit0)

This bit determines whether the Programmable Op Code filter is executed after receipt of the 7th or 8th bit of the Op Code

pub const fn prg_opcode0(&self) -> u8

Programmable OP Code 0

pub const fn set_prg_opcode0(&mut self, val: u8)

Programmable OP Code 0