nxp-pac

Crates

git

Versions

mcxa577

Flavors

Popcode1

Struct Popcode1 

#[repr(transparent)]
pub struct Popcode1(pub u32);
Programmable OP Code1

Tuple Fields

0: u32

Implementations

Source

impl Popcode1

pub const fn filter_state1(&self) -> u8

Programmable Filter state 1

pub const fn set_filter_state1(&mut self, val: u8)

Programmable Filter state 1

pub const fn filter_bit1(&self) -> FilterBit1

This bit determines whether the Programmable Op Code filter is executed after receipt of the 7th or 8th bit of the Op Code

pub const fn set_filter_bit1(&mut self, val: FilterBit1)

This bit determines whether the Programmable Op Code filter is executed after receipt of the 7th or 8th bit of the Op Code

pub const fn prg_opcode1(&self) -> u8

Programmable OP Code 1

pub const fn set_prg_opcode1(&mut self, val: u8)

Programmable OP Code 1