nxp-pac

Crates

git

Versions

mcxa577

Flavors

Popcode3

Struct Popcode3 

#[repr(transparent)]
pub struct Popcode3(pub u32);
Programmable OP Code3

Tuple Fields

0: u32

Implementations

Source

impl Popcode3

pub const fn filter_state3(&self) -> u8

Programmable Filter state 3

pub const fn set_filter_state3(&mut self, val: u8)

Programmable Filter state 3

pub const fn filter_bit3(&self) -> FilterBit3

This bit determines whether the Programmable Op Code filter is executed after receipt of the 7th or 8th bit of the Op Code

pub const fn set_filter_bit3(&mut self, val: FilterBit3)

This bit determines whether the Programmable Op Code filter is executed after receipt of the 7th or 8th bit of the Op Code

pub const fn prg_opcode3(&self) -> u8

Programmable OP Code 3

pub const fn set_prg_opcode3(&mut self, val: u8)

Programmable OP Code 3