nxp-pac

Crates

git

Versions

mcxa577

Flavors

Popcode4

Struct Popcode4 

#[repr(transparent)]
pub struct Popcode4(pub u32);
Programmable OP Code4

Tuple Fields

0: u32

Implementations

Source

impl Popcode4

pub const fn filter_state4(&self) -> u8

Programmable Filter state 4

pub const fn set_filter_state4(&mut self, val: u8)

Programmable Filter state 4

pub const fn filter_bit4(&self) -> bool

This bit determines whether the Programmable Op Code filter is executed after receipt of the 7th or 8th bit of the Op Code

pub const fn set_filter_bit4(&mut self, val: bool)

This bit determines whether the Programmable Op Code filter is executed after receipt of the 7th or 8th bit of the Op Code

pub const fn prg_opcode4(&self) -> u8

Programmable OP Code 4

pub const fn set_prg_opcode4(&mut self, val: u8)

Programmable OP Code 4