#[repr(transparent)]pub struct Isr(pub u32);Expand description
Interrupt Register
Tuple Fields
0: u32Implementations
Sourceimpl Isr
impl Isr
Sourcepub const fn set_p0_f8_int(&mut self, val: P0F8Int)
pub const fn set_p0_f8_int(&mut self, val: P0F8Int)
Indicates PORT0 F8 Op Code Command Interrupt
Sourcepub const fn set_p1_f8_int(&mut self, val: P1F8Int)
pub const fn set_p1_f8_int(&mut self, val: P1F8Int)
Indicates PORT1 F8 Op Code Command Interrupt
Sourcepub const fn p0_dirty_int(&self) -> P0DirtyInt
pub const fn p0_dirty_int(&self) -> P0DirtyInt
Indicates dirty state of the inactive Flash for P0 filter
Sourcepub const fn set_p0_dirty_int(&mut self, val: P0DirtyInt)
pub const fn set_p0_dirty_int(&mut self, val: P0DirtyInt)
Indicates dirty state of the inactive Flash for P0 filter
Sourcepub const fn p1_dirty_int(&self) -> P1DirtyInt
pub const fn p1_dirty_int(&self) -> P1DirtyInt
Indicates dirty state of the inactive Flash for P1 filter
Sourcepub const fn set_p1_dirty_int(&mut self, val: P1DirtyInt)
pub const fn set_p1_dirty_int(&mut self, val: P1DirtyInt)
Indicates dirty state of the inactive Flash for P1 filter
Sourcepub const fn p0_blk_int(&self) -> P0BlkInt
pub const fn p0_blk_int(&self) -> P0BlkInt
Indicates PORT0 Blocked Op Code Interrupt
Sourcepub const fn set_p0_blk_int(&mut self, val: P0BlkInt)
pub const fn set_p0_blk_int(&mut self, val: P0BlkInt)
Indicates PORT0 Blocked Op Code Interrupt
Sourcepub const fn p1_blk_int(&self) -> P1BlkInt
pub const fn p1_blk_int(&self) -> P1BlkInt
Indicates PORT1 Blocked Op Code Interrupt
Sourcepub const fn set_p1_blk_int(&mut self, val: P1BlkInt)
pub const fn set_p1_blk_int(&mut self, val: P1BlkInt)
Indicates PORT1 Blocked Op Code Interrupt
Sourcepub const fn p0_bytemode_int(&self) -> P0BytemodeInt
pub const fn p0_bytemode_int(&self) -> P0BytemodeInt
Indicates PORT0 Bytemode interrupt
Sourcepub const fn set_p0_bytemode_int(&mut self, val: P0BytemodeInt)
pub const fn set_p0_bytemode_int(&mut self, val: P0BytemodeInt)
Indicates PORT0 Bytemode interrupt
Sourcepub const fn p1_bytemode_int(&self) -> P1BytemodeInt
pub const fn p1_bytemode_int(&self) -> P1BytemodeInt
Indicates PORT1 Bytemode interrupt
Sourcepub const fn set_p1_bytemode_int(&mut self, val: P1BytemodeInt)
pub const fn set_p1_bytemode_int(&mut self, val: P1BytemodeInt)
Indicates PORT1 Bytemode interrupt