#[repr(transparent)]pub struct Popcode2(pub u32);Expand description
Programmable OP Code2
Tuple Fields
0: u32Implementations
Sourceimpl Popcode2
impl Popcode2
Sourcepub const fn filter_state2(&self) -> u8
pub const fn filter_state2(&self) -> u8
Programmable Filter state 2
Sourcepub const fn set_filter_state2(&mut self, val: u8)
pub const fn set_filter_state2(&mut self, val: u8)
Programmable Filter state 2
Sourcepub const fn filter_bit2(&self) -> FilterBit2
pub const fn filter_bit2(&self) -> FilterBit2
This bit determines whether the Programmable Op Code filter is executed after receipt of the 7th or 8th bit of the Op Code
Sourcepub const fn set_filter_bit2(&mut self, val: FilterBit2)
pub const fn set_filter_bit2(&mut self, val: FilterBit2)
This bit determines whether the Programmable Op Code filter is executed after receipt of the 7th or 8th bit of the Op Code
Sourcepub const fn prg_opcode2(&self) -> u8
pub const fn prg_opcode2(&self) -> u8
Programmable OP Code 0
Sourcepub const fn set_prg_opcode2(&mut self, val: u8)
pub const fn set_prg_opcode2(&mut self, val: u8)
Programmable OP Code 0