#[repr(transparent)]pub struct Popcode3(pub u32);Expand description
Programmable OP Code3
Tuple Fields
0: u32Implementations
Sourceimpl Popcode3
impl Popcode3
Sourcepub const fn filter_state3(&self) -> u8
pub const fn filter_state3(&self) -> u8
Programmable Filter state 3
Sourcepub const fn set_filter_state3(&mut self, val: u8)
pub const fn set_filter_state3(&mut self, val: u8)
Programmable Filter state 3
Sourcepub const fn filter_bit3(&self) -> FilterBit3
pub const fn filter_bit3(&self) -> FilterBit3
This bit determines whether the Programmable Op Code filter is executed after receipt of the 7th or 8th bit of the Op Code
Sourcepub const fn set_filter_bit3(&mut self, val: FilterBit3)
pub const fn set_filter_bit3(&mut self, val: FilterBit3)
This bit determines whether the Programmable Op Code filter is executed after receipt of the 7th or 8th bit of the Op Code
Sourcepub const fn prg_opcode3(&self) -> u8
pub const fn prg_opcode3(&self) -> u8
Programmable OP Code 3
Sourcepub const fn set_prg_opcode3(&mut self, val: u8)
pub const fn set_prg_opcode3(&mut self, val: u8)
Programmable OP Code 3