#[repr(transparent)]pub struct Popcode4(pub u32);Expand description
Programmable OP Code4
Tuple Fields
0: u32Implementations
Sourceimpl Popcode4
impl Popcode4
Sourcepub const fn filter_state4(&self) -> u8
pub const fn filter_state4(&self) -> u8
Programmable Filter state 4
Sourcepub const fn set_filter_state4(&mut self, val: u8)
pub const fn set_filter_state4(&mut self, val: u8)
Programmable Filter state 4
Sourcepub const fn filter_bit4(&self) -> bool
pub const fn filter_bit4(&self) -> bool
This bit determines whether the Programmable Op Code filter is executed after receipt of the 7th or 8th bit of the Op Code
Sourcepub const fn set_filter_bit4(&mut self, val: bool)
pub const fn set_filter_bit4(&mut self, val: bool)
This bit determines whether the Programmable Op Code filter is executed after receipt of the 7th or 8th bit of the Op Code
Sourcepub const fn prg_opcode4(&self) -> u8
pub const fn prg_opcode4(&self) -> u8
Programmable OP Code 4
Sourcepub const fn set_prg_opcode4(&mut self, val: u8)
pub const fn set_prg_opcode4(&mut self, val: u8)
Programmable OP Code 4